==> vue-components-1.5.20.tgz: package/lib/select/Select.vue.rd.js <==
import { useInjectStyle as he } from "../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as ve, toRefs as ye, onMounted as ke, watch as w, computed as P, ref as z, reactive as be, unref as e, openBlock as s, createElementBlock as a, createElementVNode as C, createTextVNode as we, toDisplayString as M, createCommentVNode as u, normalizeClass as $, renderSlot as f, createVNode as L, isRef as $e, createSlots as Ce, withCtx as E, normalizeProps as F, mergeProps as j, createBlock as B, withDirectives as xe, withModifiers as Se, vShow as Te, guardReactiveProps as Re, nextTick as Ie } from "vue";
import { isDefined as q, useVModels as Pe, watchDebounced as Me } from "@vueuse/core";
import { logicOr as Be, and as G, logicNot as K } from "../node_modules/@vueuse/math/index.rd.js";
import De from "../form/src/shared/ClearButton.vue.rd.js";
import "../node_modules/dayjs/dayjs.min.rd.js";
import "@vuelidate/validators";
import "@regiondev/vue-utils";
import { usePopupContainer as Ae } from "@regiondev/vue-hooks";
import "@vuelidate/core";
import { useValidation as Ne } from "../form/src/shared/hooks/useValidation.rd.js";
import Ve from "../form/src/shared/ValidationMessage.vue.rd.js";
import ze from "./SelectDropdown.vue.rd.js";
import Le from "./multiple/SelectedTags.vue.rd.js";
import { selectProps as Ee } from "./selectProps.rd.js";
import { useSelections as Fe } from "./hooks/useMultipleSelections.rd.js";
import "../spinners/index.rd.js";
import je from "../shared/styles/validations.scss.rd.js";
import qe from "../spinners/src/Spinner.vue.rd.js";
const Ge = { class: "-mb-0.5 flex flex-row" }, Ke = {
  key: 0,
  class: "mb-0 fs-small font-bold text-dark-200 dark:text-gray-400"
}, Oe = {
  key: 0,
  class: "text-lg text-red-600"
}, Ue = {
  key: 1,
  class: "fs-small mb-0 relative ml-auto font-bold !text-xs text-muted"
}, He = { class: "absolute bottom-0 right-1" }, Je = ["value", "disabled", "placeholder"], Qe = {
  key: 4,
  class: "px-3 inline-flex"
}, We = {
  key: 5,
  class: "w-fit-content flex rounded-full mr-2"
}, Xe = /* @__PURE__ */ C("span", { class: "text-gray-500 text-2xl i-carbon:chevron-sort" }, null, -1), Ye = [
  Xe
], Ze = {
  key: 6,
  class: "px-3"
}, yt = /* @__PURE__ */ ve({
  __name: "Select",
  props: Ee(),
  emits: [
    "update:modelValue",
    "update:selectedItem",
    "update:selectedItems",
    "onblur",
    "changeValue",
    "clickedItem",
    "clear"
  ],
  setup(O, { expose: U, emit: h }) {
    const m = O;
    he(je, "animations-css");
    const {
      modelValue: l,
      multiple: n,
      idKey: x,
      requiredMark: H,
      textKey: S,
      items: v,
      label: T,
      loading: J,
      disabled: d,
      defaultValue: R,
      size: o,
      placeholder: Q,
      customRender: y,
      allowClear: D,
      containerClass: W
    } = ye(m), {
      clear: X,
      inputRef: Y,
      focused: Z,
      handleChange: I,
      vobject: _,
      stateClasses: ee,
      getText: te,
      validateStatus: le,
      formContainer: oe,
      validate: se,
      isLoading: re,
      blurInput: ae
    } = Ne(q(m.validations));
    ke(() => {
      R && R.value && !(l != null && l.value) && I({ target: { value: R.value } });
    }), w(
      () => m.modelValue,
      (t) => {
        h("changeValue", t);
      }
    );
    const ne = P(() => i != null && i.value ? y != null && y.value ? y.value(i.value) : i.value[S.value] : null), { onSelect: ie, removeSelection: de, clearSelection: ue } = Fe();
    async function me() {
      Ie(() => {
        var t;
        return (t = N.value) == null ? void 0 : t.focusFilter();
      });
    }
    function A() {
      ue(), X(), ae(), h("clear");
    }
    const N = z(), k = be(/* @__PURE__ */ new Map());
    w(
      () => v == null ? void 0 : v.value,
      (t) => {
        k.clear(), t == null || t.forEach((r) => {
          k.set(r[e(x)], r);
        });
      },
      { immediate: !0 }
    );
    const c = P(() => {
      if (n.value && l && Array.isArray(l.value)) {
        const t = [];
        for (let r = 0; r < l.value.length; r++) {
          const b = l.value[r];
          t.push(k.get(b));
        }
        return t;
      }
      return [];
    }), i = P(() => !n.value && (l != null && l.value) ? k.get(l == null ? void 0 : l.value) : null);
    w(i, () => {
      h("update:selectedItem", i.value);
    }), w(c, () => {
      h("update:selectedItems", c.value);
    });
    const { filter: fe } = Pe(m), p = z(), ce = Be(
      G(D, K(J), K(n), q(l == null ? void 0 : l.value)),
      G(D, n)
    );
    Me(p, () => fe.value = p.value, {
      debounce: m.debounceMs
    });
    const { container: pe, getContainer: ge } = Ae(m.getPopupContainer);
    return U({
      validate: se,
      clear: A,
      selectedItems: c,
      selectedItem: i
    }), (t, r) => {
      var b, V;
      return s(), a("div", {
        ref_key: "container",
        ref: pe,
        class: ""
      }, [
        C("div", Ge, [
          e(T) ? (s(), a("label", Ke, [
            we(M(e(T)) + " ", 1),
            (b = e(_)) != null && b.required && e(H) ? (s(), a("span", Oe, "*")) : u("", !0)
          ])) : u("", !0),
          t.maxSelections && e(n) ? (s(), a("label", Ue, [
            C("span", He, M(((V = e(l)) == null ? void 0 : V.length) || 0) + "/" + M(t.maxSelections), 1)
          ])) : u("", !0)
        ]),
        C("div", {
          ref_key: "formContainer",
          ref: oe,
          class: $([[
            {
              focused: e(Z),
              "mt-0.5": e(T),
              "cursor-not-allowed": e(d),
              "min-h-11": e(o) == "xlarge" && !t.$slots.default,
              "min-h-9": e(o) == "large" && !t.$slots.default,
              "min-h-8": e(o) == "medium" && !t.$slots.default,
              "min-h-7": e(o) == "small" && !t.$slots.default
            }
          ], "relative flex !shadow-sm app-input-container group"])
        }, [
          f(t.$slots, "addonBefore"),
          L(ze, {
            ref_key: "selectDropdown",
            ref: N,
            filter: e(p),
            "onUpdate:filter": r[1] || (r[1] = (g) => $e(p) ? p.value = g : null),
            multiple: e(n),
            items: e(v),
            class: $(["!block w-full !h-full", {
              "min-h-11": e(o) == "xlarge" && !t.$slots.default,
              "min-h-9": e(o) == "large" && !t.$slots.default,
              "min-h-8": e(o) == "medium" && !t.$slots.default,
              "min-h-7": e(o) == "small" && !t.$slots.default
            }]),
            selected: e(l),
            hideSelected: t.hideSelected,
            "text-key": e(S),
            "id-key": e(x),
            disabled: e(d),
            loading: t.loadingData,
            "show-filter": t.showFilter,
            trigger: t.trigger,
            getPopupContainer: e(ge),
            onClickedItem: e(ie)
          }, Ce({
            default: E(() => [
              t.$slots.default ? (s(), a("div", {
                key: 1,
                class: $(["", { "opacity-60 pointer-events-none !cursor-not-allowed": e(d) }])
              }, [
                f(t.$slots, "default")
              ], 2)) : (s(), a("div", {
                key: 0,
                class: $(["focus-within:bg-white focus-within:!bg-transparent focus-within:ring-1 focus-within:dark:bg-slate-800 dark:border-slate-700 dark:text-white flex items-center border-1px border-solid light:!border-slate-300 rounded-lg relative !w-full light:focus-within:!border-primary-500 focus-within:!border-primary-500 focus-within:!ring-primary-500", [
                  e(W),
                  {
                    ...e(ee),
                    "py-1": e(n),
                    "cursor-not-allowed": e(d),
                    "hover:bg-light-500 dark:hover:bg-slate-700/30": !e(d) && !(e(n) && e(c).length),
                    "bg-slate-200 hover:bg-slate-200 bg-opacity-70 dark:bg-slate-900/70 dark:text-slate-400": t.isGray,
                    "bg-surface": !t.isGray,
                    "rounded-l-none": t.$slots.addonBefore,
                    "rounded-r-none": t.$slots.addonAfter,
                    "min-h-11": e(o) == "xlarge" && !t.$slots.default,
                    "min-h-9": e(o) == "large" && !t.$slots.default,
                    "min-h-8": e(o) == "medium" && !t.$slots.default,
                    "min-h-7": e(o) == "small" && !t.$slots.default
                  }
                ]]),
                onClick: me
              }, [
                t.$slots.inputRender ? f(t.$slots, "inputRender", F(j({ key: 0 }, { item: e(i) }))) : u("", !0),
                e(n) ? (s(), B(Le, {
                  key: 2,
                  tags: e(c),
                  "text-key": e(S),
                  "id-key": e(x),
                  maxTagCount: t.maxTagCount,
                  maxTagTextLength: t.maxTagTextLength,
                  onRemoveTag: e(de)
                }, null, 8, ["tags", "text-key", "id-key", "maxTagCount", "maxTagTextLength", "onRemoveTag"])) : (s(), a("input", j({
                  key: 1,
                  ref_key: "inputRef",
                  ref: Y,
                  autocomplete: "off",
                  readonly: "",
                  role: "combobox"
                }, t.$attrs, {
                  value: e(ne),
                  disabled: e(d),
                  placeholder: e(Q),
                  class: ["outline-none text-theme w-full border-none text-sm bg-transparent rounded-md w-full text-sm text-black-600 placeholder-gray-500", {
                    "pl-3": !t.$slots.iconPrefix && !t.$slots.prefix,
                    "cursor-not-allowed": e(d),
                    "py-2": e(o) == "large" || e(o) == "xlarge",
                    "pl-2 py-1 ": e(o) == "medium",
                    "pl-2 py-0": e(o) == "small"
                  }],
                  onInput: r[0] || (r[0] = (...g) => e(I) && e(I)(...g))
                }), null, 16, Je)),
                e(ce) ? xe((s(), B(De, {
                  key: 3,
                  class: "pl-1 ml-auto pr-2",
                  onClick: Se(A, ["prevent", "stop"])
                }, null, 8, ["onClick"])), [
                  [Te, e(l)]
                ]) : u("", !0),
                e(re) ? (s(), a("div", Qe, [
                  L(e(qe), {
                    loading: !0,
                    size: "18",
                    inherit: !0,
                    class: "text-gray-400"
                  })
                ])) : (s(), a("div", We, Ye)),
                t.$slots.suffix ? (s(), a("div", Ze, [
                  f(t.$slots, "suffix")
                ])) : u("", !0)
              ], 2))
            ]),
            _: 2
          }, [
            t.$slots.itemRender ? {
              name: "itemRender",
              fn: E(({ item: g }) => [
                f(t.$slots, "itemRender", F(Re({ item: g })))
              ]),
              key: "0"
            } : void 0
          ]), 1032, ["filter", "multiple", "items", "class", "selected", "hideSelected", "text-key", "id-key", "disabled", "loading", "show-filter", "trigger", "getPopupContainer", "onClickedItem"]),
          f(t.$slots, "addonAfter")
        ], 2),
        !t.simple && !t.$slots.default ? (s(), B(Ve, {
          key: 0,
          state: e(le),
          hint: e(te)
        }, null, 8, ["state", "hint"])) : u("", !0)
      ], 512);
    };
  }
});
export {
  yt as default
};

==> vue-components-1.5.23.tgz: package/lib/select/Select.vue.rd.js <==
import { useInjectStyle as he } from "../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as ve, toRefs as ye, onMounted as ke, watch as w, computed as P, ref as z, reactive as be, unref as e, openBlock as s, createElementBlock as a, createElementVNode as C, createTextVNode as we, toDisplayString as M, createCommentVNode as u, normalizeClass as $, renderSlot as f, createVNode as L, isRef as $e, createSlots as Ce, withCtx as E, normalizeProps as F, mergeProps as j, createBlock as B, withDirectives as xe, withModifiers as Se, vShow as Te, guardReactiveProps as Re, nextTick as Ie } from "vue";
import { isDefined as q, useVModels as Pe, watchDebounced as Me } from "@vueuse/core";
import { logicOr as Be, and as G, logicNot as K } from "../node_modules/@vueuse/math/index.rd.js";
import De from "../form/src/shared/ClearButton.vue.rd.js";
import "../node_modules/dayjs/dayjs.min.rd.js";
import "@vuelidate/validators";
import "@regiondev/vue-utils";
import { usePopupContainer as Ae } from "@regiondev/vue-hooks";
import "@vuelidate/core";
import { useValidation as Ne } from "../form/src/shared/hooks/useValidation.rd.js";
import Ve from "../form/src/shared/ValidationMessage.vue.rd.js";
import ze from "./SelectDropdown.vue.rd.js";
import Le from "./multiple/SelectedTags.vue.rd.js";
import { selectProps as Ee } from "./selectProps.rd.js";
import { useSelections as Fe } from "./hooks/useMultipleSelections.rd.js";
import "../spinners/index.rd.js";
import je from "../shared/styles/validations.scss.rd.js";
import qe from "../spinners/src/Spinner.vue.rd.js";
const Ge = { class: "-mb-0.5 flex flex-row" }, Ke = {
  key: 0,
  class: "mb-0 fs-small font-bold text-dark-200 dark:text-gray-400"
}, Oe = {
  key: 0,
  class: "text-lg text-red-600"
}, Ue = {
  key: 1,
  class: "fs-small mb-0 relative ml-auto font-bold !text-xs text-muted"
}, He = { class: "absolute bottom-0 right-1" }, Je = ["value", "disabled", "placeholder"], Qe = {
  key: 4,
  class: "px-3 inline-flex"
}, We = {
  key: 5,
  class: "w-fit-content flex rounded-full mr-2"
}, Xe = /* @__PURE__ */ C("span", { class: "text-gray-500 text-2xl i-carbon:chevron-sort" }, null, -1), Ye = [
  Xe
], Ze = {
  key: 6,
  class: "px-3"
}, yt = /* @__PURE__ */ ve({
  __name: "Select",
  props: Ee(),
  emits: [
    "update:modelValue",
    "update:selectedItem",
    "update:selectedItems",
    "onblur",
    "changeValue",
    "clickedItem",
    "clear"
  ],
  setup(O, { expose: U, emit: h }) {
    const m = O;
    he(je, "animations-css");
    const {
      modelValue: l,
      multiple: n,
      idKey: x,
      requiredMark: H,
      textKey: S,
      items: v,
      label: T,
      loading: J,
      disabled: d,
      defaultValue: R,
      size: o,
      placeholder: Q,
      customRender: y,
      allowClear: D,
      containerClass: W
    } = ye(m), {
      clear: X,
      inputRef: Y,
      focused: Z,
      handleChange: I,
      vobject: _,
      stateClasses: ee,
      getText: te,
      validateStatus: le,
      formContainer: oe,
      validate: se,
      isLoading: re,
      blurInput: ae
    } = Ne(q(m.validations));
    ke(() => {
      R && R.value && !(l != null && l.value) && I({ target: { value: R.value } });
    }), w(
      () => m.modelValue,
      (t) => {
        h("changeValue", t);
      }
    );
    const ne = P(() => i != null && i.value ? y != null && y.value ? y.value(i.value) : i.value[S.value] : null), { onSelect: ie, removeSelection: de, clearSelection: ue } = Fe();
    async function me() {
      Ie(() => {
        var t;
        return (t = N.value) == null ? void 0 : t.focusFilter();
      });
    }
    function A() {
      ue(), X(), ae(), h("clear");
    }
    const N = z(), k = be(/* @__PURE__ */ new Map());
    w(
      () => v == null ? void 0 : v.value,
      (t) => {
        k.clear(), t == null || t.forEach((r) => {
          k.set(r[e(x)], r);
        });
      },
      { immediate: !0 }
    );
    const c = P(() => {
      if (n.value && l && Array.isArray(l.value)) {
        const t = [];
        for (let r = 0; r < l.value.length; r++) {
          const b = l.value[r];
          t.push(k.get(b));
        }
        return t;
      }
      return [];
    }), i = P(() => !n.value && (l != null && l.value) ? k.get(l == null ? void 0 : l.value) : null);
    w(i, () => {
      h("update:selectedItem", i.value);
    }), w(c, () => {
      h("update:selectedItems", c.value);
    });
    const { filter: fe } = Pe(m), p = z(), ce = Be(
      G(D, K(J), K(n), q(l == null ? void 0 : l.value)),
      G(D, n)
    );
    Me(p, () => fe.value = p.value, {
      debounce: m.debounceMs
    });
    const { container: pe, getContainer: ge } = Ae(m.getPopupContainer);
    return U({
      validate: se,
      clear: A,
      selectedItems: c,
      selectedItem: i
    }), (t, r) => {
      var b, V;
      return s(), a("div", {
        ref_key: "container",
        ref: pe,
        class: ""
      }, [
        C("div", Ge, [
          e(T) ? (s(), a("label", Ke, [
            we(M(e(T)) + " ", 1),
            (b = e(_)) != null && b.required && e(H) ? (s(), a("span", Oe, "*")) : u("", !0)
          ])) : u("", !0),
          t.maxSelections && e(n) ? (s(), a("label", Ue, [
            C("span", He, M(((V = e(l)) == null ? void 0 : V.length) || 0) + "/" + M(t.maxSelections), 1)
          ])) : u("", !0)
        ]),
        C("div", {
          ref_key: "formContainer",
          ref: oe,
          class: $([[
            {
              focused: e(Z),
              "mt-0.5": e(T),
              "cursor-not-allowed": e(d),
              "min-h-11": e(o) == "xlarge" && !t.$slots.default,
              "min-h-9": e(o) == "large" && !t.$slots.default,
              "min-h-8": e(o) == "medium" && !t.$slots.default,
              "min-h-7": e(o) == "small" && !t.$slots.default
            }
          ], "relative flex !shadow-sm app-input-container group"])
        }, [
          f(t.$slots, "addonBefore"),
          L(ze, {
            ref_key: "selectDropdown",
            ref: N,
            filter: e(p),
            "onUpdate:filter": r[1] || (r[1] = (g) => $e(p) ? p.value = g : null),
            multiple: e(n),
            items: e(v),
            class: $(["!block w-full !h-full", {
              "min-h-11": e(o) == "xlarge" && !t.$slots.default,
              "min-h-9": e(o) == "large" && !t.$slots.default,
              "min-h-8": e(o) == "medium" && !t.$slots.default,
              "min-h-7": e(o) == "small" && !t.$slots.default
            }]),
            selected: e(l),
            hideSelected: t.hideSelected,
            "text-key": e(S),
            "id-key": e(x),
            disabled: e(d),
            loading: t.loadingData,
            "show-filter": t.showFilter,
            trigger: t.trigger,
            getPopupContainer: e(ge),
            onClickedItem: e(ie)
          }, Ce({
            default: E(() => [
              t.$slots.default ? (s(), a("div", {
                key: 1,
                class: $(["", { "opacity-60 pointer-events-none !cursor-not-allowed": e(d) }])
              }, [
                f(t.$slots, "default")
              ], 2)) : (s(), a("div", {
                key: 0,
                class: $(["focus-within:bg-white focus-within:!bg-transparent focus-within:ring-1 focus-within:dark:bg-slate-800 dark:border-slate-700 dark:text-white flex items-center border-1px border-solid light:!border-slate-300 rounded-lg relative !w-full light:focus-within:!border-primary-500 focus-within:!border-primary-500 focus-within:!ring-primary-500", [
                  e(W),
                  {
                    ...e(ee),
                    "py-1": e(n),
                    "cursor-not-allowed": e(d),
                    "hover:bg-light-500 dark:hover:bg-slate-700/30": !e(d) && !(e(n) && e(c).length),
                    "bg-slate-200 hover:bg-slate-200 bg-opacity-70 dark:bg-slate-900/70 dark:text-slate-400": t.isGray,
                    "bg-surface": !t.isGray,
                    "rounded-l-none": t.$slots.addonBefore,
                    "rounded-r-none": t.$slots.addonAfter,
                    "min-h-11": e(o) == "xlarge" && !t.$slots.default,
                    "min-h-9": e(o) == "large" && !t.$slots.default,
                    "min-h-8": e(o) == "medium" && !t.$slots.default,
                    "min-h-7": e(o) == "small" && !t.$slots.default
                  }
                ]]),
                onClick: me
              }, [
                t.$slots.inputRender ? f(t.$slots, "inputRender", F(j({ key: 0 }, { item: e(i) }))) : u("", !0),
                e(n) ? (s(), B(Le, {
                  key: 2,
                  tags: e(c),
                  "text-key": e(S),
                  "id-key": e(x),
                  maxTagCount: t.maxTagCount,
                  maxTagTextLength: t.maxTagTextLength,
                  onRemoveTag: e(de)
                }, null, 8, ["tags", "text-key", "id-key", "maxTagCount", "maxTagTextLength", "onRemoveTag"])) : (s(), a("input", j({
                  key: 1,
                  ref_key: "inputRef",
                  ref: Y,
                  autocomplete: "off",
                  readonly: "",
                  role: "combobox"
                }, t.$attrs, {
                  value: e(ne),
                  disabled: e(d),
                  placeholder: e(Q),
                  class: ["outline-none text-theme w-full border-none text-sm bg-transparent rounded-md w-full text-sm text-black-600 placeholder-gray-500", {
                    "pl-3": !t.$slots.iconPrefix && !t.$slots.prefix,
                    "cursor-not-allowed": e(d),
                    "py-2": e(o) == "large" || e(o) == "xlarge",
                    "pl-2 py-1 ": e(o) == "medium",
                    "pl-2 py-0": e(o) == "small"
                  }],
                  onInput: r[0] || (r[0] = (...g) => e(I) && e(I)(...g))
                }), null, 16, Je)),
                e(ce) ? xe((s(), B(De, {
                  key: 3,
                  class: "pl-1 ml-auto pr-2",
                  onClick: Se(A, ["prevent", "stop"])
                }, null, 8, ["onClick"])), [
                  [Te, e(l)]
                ]) : u("", !0),
                e(re) ? (s(), a("div", Qe, [
                  L(e(qe), {
                    loading: !0,
                    size: "18",
                    inherit: !0,
                    class: "text-gray-400"
                  })
                ])) : (s(), a("div", We, Ye)),
                t.$slots.suffix ? (s(), a("div", Ze, [
                  f(t.$slots, "suffix")
                ])) : u("", !0)
              ], 2))
            ]),
            _: 2
          }, [
            t.$slots.itemRender ? {
              name: "itemRender",
              fn: E(({ item: g }) => [
                f(t.$slots, "itemRender", F(Re({ item: g })))
              ]),
              key: "0"
            } : void 0
          ]), 1032, ["filter", "multiple", "items", "class", "selected", "hideSelected", "text-key", "id-key", "disabled", "loading", "show-filter", "trigger", "getPopupContainer", "onClickedItem"]),
          f(t.$slots, "addonAfter")
        ], 2),
        !t.simple && !t.$slots.default ? (s(), B(Ve, {
          key: 0,
          state: e(le),
          hint: e(te),
          "info-text": t.infoText
        }, null, 8, ["state", "hint", "info-text"])) : u("", !0)
      ], 512);
    };
  }
});
export {
  yt as default
};
